aboutsummaryrefslogtreecommitdiffstats
path: root/feature-healthcheck/src/main/java
diff options
context:
space:
mode:
authorJim Hahn <jrh3@att.com>2019-08-05 15:27:16 -0400
committerJim Hahn <jrh3@att.com>2019-08-13 15:58:15 -0400
commita156cf3cbad6512510ae9a02a13c0408f901c734 (patch)
tree0a69bffb2a6c9f961bda1408153cf44f360c6a17 /feature-healthcheck/src/main/java
parent62d1ff054b0ec6348ab6f7415063fdaa3f425215 (diff)
Fix sonar issues in drools-pdp
Address sonar issue, "Move constants to a class or enum", by moving them from interfaces to classes: ActiveStandbyFeatureApi StateManagementFeatureApi PolicyResourceLockFeatureApi PolicySessionFeatureApi DroolsController DroolsControllerFeatureApi PolicyControllerFeatureApi PolicyEngineFeatureApi HealthCheck SystemPersistence EventProtocolCoder PolicyController PolicyEngine TestTransaction MdcTransaction Address sonar issue, "Move constants to a class or enum", by change the interface to a class: DroolsProperties Address sonar issue, "Override the "equals" method in this class", by adding equals & hashCode to: DroolsPdpEntity DroolsPdpImpl Use lombok for a number of getters & setters. Address sonar issue, "Define a constant instead of duplicating this literal" in: DroolsPdpsElectionHandler JpaDroolsPdpsConnector MavenDroolsController GenericEventProtocolCoder GsonProtocolCoderToolset RestManager Address sonar issue, "Remove the parentheses around the parameter" in: MavenDroolsController Address sonar issue, "Replace this lambda with a method reference" in: LifecycleFsm Address sonar issue, "Move this constructor to comply with Java Code Conventions" in: LifecycleStateRunning Address sonar issue, "Replace this 'switch' statement by 'if' statements to increase readability", as specified in: PolicyEngineManager Address sonar issue, "Rename field to prevent any misunderstanding/clash with field" in: MdcTransactionImpl Address sonar issue, "Either log or rethrow this exception", in: RestManager Address sonar issue, "Rename this constant name to" uppercase, by replacing enums with static lists in: RestManager Addressed review comments: Fixed license dates. Renamed getSiteName/setSiteName methods to getSite/setSite in the interface to match the field names in the implementation classes. Renamed *Instance classes to *Constants. Next round of review comments. Change-Id: I1c26af9f194833dd773f2b25dc5f60cde163201c Issue-ID: POLICY-1968 Signed-off-by: Jim Hahn <jrh3@att.com>
Diffstat (limited to 'feature-healthcheck/src/main/java')
-rw-r--r--feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheck.java5
-rw-r--r--feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckConstants.java36
-rw-r--r--feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckFeature.java18
-rw-r--r--feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckManager.java (renamed from feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckMonitor.java)11
-rw-r--r--feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/RestHealthCheck.java18
5 files changed, 60 insertions, 28 deletions
diff --git a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheck.java b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheck.java
index 1a4dab6b..b1b28f79 100644
--- a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheck.java
+++ b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheck.java
@@ -30,11 +30,6 @@ import org.onap.policy.common.capabilities.Startable;
public interface HealthCheck extends Startable {
/**
- * Healthcheck Monitor.
- */
- public static final HealthCheck monitor = new HealthCheckMonitor();
-
- /**
* Healthcheck Report.
*/
public static class Report {
diff --git a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckConstants.java b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckConstants.java
new file mode 100644
index 00000000..70b241dd
--- /dev/null
+++ b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckConstants.java
@@ -0,0 +1,36 @@
+/*
+ * ============LICENSE_START=======================================================
+ * feature-healthcheck
+ * ================================================================================
+ * Copyright (C) 2019 AT&T Intellectual Property. All rights reserved.
+ * ================================================================================
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ * ============LICENSE_END=========================================================
+ */
+
+package org.onap.policy.drools.healthcheck;
+
+import lombok.Getter;
+
+public class HealthCheckConstants {
+
+ /**
+ * Healthcheck Monitor.
+ */
+ @Getter
+ private static final HealthCheck manager = new HealthCheckManager();
+
+ private HealthCheckConstants() {
+ // do nothing
+ }
+}
diff --git a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckMonitor.java b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckManager.java
index cca56e01..f0b9313a 100644
--- a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckMonitor.java
+++ b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckManager.java
@@ -30,8 +30,9 @@ import org.onap.policy.common.endpoints.http.client.HttpClientFactoryInstance;
import org.onap.policy.common.endpoints.http.server.HttpServletServer;
import org.onap.policy.common.endpoints.http.server.HttpServletServerFactory;
import org.onap.policy.common.endpoints.http.server.HttpServletServerFactoryInstance;
-import org.onap.policy.drools.persistence.SystemPersistence;
+import org.onap.policy.drools.persistence.SystemPersistenceConstants;
import org.onap.policy.drools.system.PolicyEngine;
+import org.onap.policy.drools.system.PolicyEngineConstants;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
@@ -39,12 +40,12 @@ import org.slf4j.LoggerFactory;
/**
* Healthcheck Monitor.
*/
-public class HealthCheckMonitor implements HealthCheck {
+public class HealthCheckManager implements HealthCheck {
/**
* Logger.
*/
- private static Logger logger = LoggerFactory.getLogger(HealthCheckMonitor.class);
+ private static Logger logger = LoggerFactory.getLogger(HealthCheckManager.class);
/**
* Attached http servers.
@@ -233,7 +234,7 @@ public class HealthCheckMonitor implements HealthCheck {
// the following methods may be overridden by junit tests
protected PolicyEngine getEngineManager() {
- return PolicyEngine.manager;
+ return PolicyEngineConstants.getManager();
}
protected HttpServletServerFactory getServerFactory() {
@@ -245,6 +246,6 @@ public class HealthCheckMonitor implements HealthCheck {
}
protected Properties getPersistentProperties(String propertyName) {
- return SystemPersistence.manager.getProperties(propertyName);
+ return SystemPersistenceConstants.getManager().getProperties(propertyName);
}
}
diff --git a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/RestHealthCheck.java b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/RestHealthCheck.java
index 5047cb26..954a2c55 100644
--- a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/RestHealthCheck.java
+++ b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/RestHealthCheck.java
@@ -2,14 +2,14 @@
* ============LICENSE_START=======================================================
* feature-healthcheck
* ================================================================================
- * Copyright (C) 2017-2018 AT&T Intellectual Property. All rights reserved.
+ * Copyright (C) 2017-2019 AT&T Intellectual Property. All rights reserved.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
+ *
* http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -56,24 +56,24 @@ public class RestHealthCheck {
@Path("healthcheck")
@Produces(MediaType.APPLICATION_JSON)
@ApiOperation(
- value = "Perform a system healthcheck",
+ value = "Perform a system healthcheck",
notes = "Provides healthy status of the PDP-D plus the components defined in its "
+ "configuration by using a REST interface",
response = Reports.class
)
- public Response healthcheck() {
- return Response.status(Response.Status.OK).entity(HealthCheck.monitor.healthCheck()).build();
+ public Response healthcheck() {
+ return Response.status(Response.Status.OK).entity(HealthCheckConstants.getManager().healthCheck()).build();
}
@GET
@Path("healthcheck/configuration")
@Produces(MediaType.APPLICATION_JSON)
@ApiOperation(
- value = "Configuration",
+ value = "Configuration",
notes = "Provides the Healthcheck server configuration and monitored REST clients",
response = HealthCheck.class
)
- public HealthCheck configuration() {
- return HealthCheck.monitor;
+ public HealthCheck configuration() {
+ return HealthCheckConstants.getManager();
}
}
diff --git a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckFeature.java b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckFeature.java
index af638c75..961f4a1d 100644
--- a/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckFeature.java
+++ b/feature-healthcheck/src/main/java/org/onap/policy/drools/healthcheck/HealthCheckFeature.java
@@ -7,9 +7,9 @@
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
+ *
* http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -33,7 +33,7 @@ public class HealthCheckFeature implements PolicyEngineFeatureApi {
/**
* Logger.
*/
- private static Logger logger = LoggerFactory.getLogger(HealthCheckFeature.class);
+ private static Logger logger = LoggerFactory.getLogger(HealthCheckFeature.class);
/**
* Properties Configuration Name.
@@ -48,7 +48,7 @@ public class HealthCheckFeature implements PolicyEngineFeatureApi {
@Override
public boolean afterStart(PolicyEngine engine) {
try {
- getMonitor().start();
+ getManager().start();
} catch (IllegalStateException e) {
logger.error("Healthcheck Monitor cannot be started", e);
}
@@ -59,7 +59,7 @@ public class HealthCheckFeature implements PolicyEngineFeatureApi {
@Override
public boolean afterShutdown(PolicyEngine engine) {
try {
- getMonitor().stop();
+ getManager().stop();
} catch (IllegalStateException e) {
logger.error("Healthcheck Monitor cannot be stopped", e);
}
@@ -69,11 +69,11 @@ public class HealthCheckFeature implements PolicyEngineFeatureApi {
/**
* Gets the monitor.
*
* @return the healthcheck monitor
*/
- public HealthCheck getMonitor() {
- return HealthCheck.monitor;
+ public HealthCheck getManager() {
+ return HealthCheckConstants.getManager();
}
}
@@ -69,11 +69,11 @@ public class HealthCheckFeature implements PolicyEngineFeatureApi {
/**
* Gets the monitor.
- *
- * @return the healthcheck monitor
+ *
+ * @return the healthcheck manager
*/